@@ -21,8 +21,7 @@ ties = 0
 #Difficulties
 class difficulty(Enum):
     Easy = 1
-    Medium = 2
-    Hard = 3
+    Hard = 2
 
 #Prompt the user for choice of difficulty and returns difficulty 
 #if the difficulty begins with the input.
@@ -31,7 +30,7 @@ def chooseDifficulty() :
     if ("easy").startswith(playerInput.lower()): 
         return difficulty.Easy
     elif ("hard").startswith(playerInput.lower()): 
-        return difficulty.Medium
+        return difficulty.Hard
     else:
         return None
 
