@@ -21,10 +21,8 @@ def main():
     #Prompting game difficulty
     difficulty = ML.chooseDifficulty()
     if (difficulty.value == 1) :
-        print("You chose difficulty! Computer will be on random mode.") 
+        print("You chose easy difficulty! Computer will be on random mode.") 
     elif (difficulty.value == 2) :
-        print("You chose medium difficulty! Computer will be using history matching.")
-    elif (difficulty.value == 3) :
         print("You chose hard difficulty! Computer will be using history matching.")
 
     # if user enters difficulty greater than easy, ask user if they want to turn on text-detail mode (to see how computer tracks history)
@@ -57,7 +55,7 @@ def main():
             if round >= 3 :
                 #If there is a successful prediction, the computer choice will be chosen to counter the predicted player item.
                 # pass showDetails... if true then the func will print out 
-                predictedPlayerItem = (ML.ML_callHistoryMatching("computer", showDetails))
+                predictedPlayerItem = (ML.ML_historyMatching("computer", showDetails))
                 if (predictedPlayerItem  != None) :
                     #only print predicted move if in text-detail mode
                     if(showDetails):
